==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/ArrayElement.h <==
// public class soot.jimple.spark.pag.ArrayElement

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 941a5ecbd6f1b874 soot_jimple_spark_pag_ArrayElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_ArrayElement_H_
#define _JC_soot_jimple_spark_pag_ArrayElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_spark_pag_ArrayElement$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$sub_refs	_jc_soot_jimple_spark_pag_ArrayElement$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs	_jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$refs	_jc_soot_jimple_spark_pag_ArrayElement$refs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$nonrefs	_jc_soot_jimple_spark_pag_ArrayElement$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$object	_jc_soot_jimple_spark_pag_ArrayElement$object;

typedef const struct _jc_soot_jimple_spark_pag_ArrayElement$vmethods	_jc_soot_jimple_spark_pag_ArrayElement$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ArrayElement$vtable	_jc_soot_jimple_spark_pag_ArrayElement$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ArrayElement$vtype	_jc_soot_jimple_spark_pag_ArrayElement$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ArrayElement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *);
extern void _jc_soot_jimple_spark_pag_ArrayElement$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern jint _jc_soot_jimple_spark_pag_ArrayElement$method$getNumber$9f4729baae2d2787(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *);
extern void _jc_soot_jimple_spark_pag_ArrayElement$method$setNumber$72e40df050255abc(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_ArrayElement$method_info$getNumber$9f4729baae2d2787;
extern _jc_method _jc_soot_jimple_spark_pag_ArrayElement$method_info$setNumber$72e40df050255abc;

// Static methods
extern struct _jc_soot_jimple_spark_pag_ArrayElement$object *_jc_soot_jimple_spark_pag_ArrayElement$method$v$f7ee236d690e4697(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ArrayElement$vmethods {
	jint	(*getNumber$9f4729baae2d2787)(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *);
	void	(*setNumber$72e40df050255abc)(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *, jint);
};

// Vtable
struct _jc_soot_jimple_spark_pag_ArrayElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_ArrayElement$vmethods	soot_jimple_spark_pag_ArrayElement;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ArrayElement$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ArrayElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ArrayElement$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ArrayElement$refs {
    _jc_soot_jimple_spark_pag_ArrayElement$sub_refs	soot_jimple_spark_pag_ArrayElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs {
	jint	number;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ArrayElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs	soot_jimple_spark_pag_ArrayElement;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ArrayElement$object {
	_jc_soot_jimple_spark_pag_ArrayElement$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ArrayElement$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ArrayElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ArrayElement$vtype _jc_soot_jimple_spark_pag_ArrayElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ArrayElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ArrayElement$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ArrayElement_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/ArrayElement.h <==
// public class soot.jimple.spark.pag.ArrayElement

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 941a5ecbd6f1b874 soot_jimple_spark_pag_ArrayElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_ArrayElement_H_
#define _JC_soot_jimple_spark_pag_ArrayElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_spark_pag_ArrayElement$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$sub_refs	_jc_soot_jimple_spark_pag_ArrayElement$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs	_jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$refs	_jc_soot_jimple_spark_pag_ArrayElement$refs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$nonrefs	_jc_soot_jimple_spark_pag_ArrayElement$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ArrayElement$object	_jc_soot_jimple_spark_pag_ArrayElement$object;

typedef const struct _jc_soot_jimple_spark_pag_ArrayElement$vmethods	_jc_soot_jimple_spark_pag_ArrayElement$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ArrayElement$vtable	_jc_soot_jimple_spark_pag_ArrayElement$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ArrayElement$vtype	_jc_soot_jimple_spark_pag_ArrayElement$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ArrayElement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_ArrayElement$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_jimple_spark_pag_ArrayElement$method$getNumber$9f4729baae2d2787(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_ArrayElement$method$setNumber$72e40df050255abc(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_ArrayElement$method_info$getNumber$9f4729baae2d2787;
extern _jc_method _jc_soot_jimple_spark_pag_ArrayElement$method_info$setNumber$72e40df050255abc;

// Static methods
extern struct _jc_soot_jimple_spark_pag_ArrayElement$object *_jc_soot_jimple_spark_pag_ArrayElement$method$v$f7ee236d690e4697(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ArrayElement$vmethods {
	jint	(*getNumber$9f4729baae2d2787)(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *) _JC_JCNI_ATTR;
	void	(*setNumber$72e40df050255abc)(_jc_env *, struct _jc_soot_jimple_spark_pag_ArrayElement$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_ArrayElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_ArrayElement$vmethods	soot_jimple_spark_pag_ArrayElement;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ArrayElement$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ArrayElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ArrayElement$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ArrayElement$refs {
    _jc_soot_jimple_spark_pag_ArrayElement$sub_refs	soot_jimple_spark_pag_ArrayElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs {
	jint	number;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ArrayElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_ArrayElement$sub_nonrefs	soot_jimple_spark_pag_ArrayElement;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ArrayElement$object {
	_jc_soot_jimple_spark_pag_ArrayElement$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ArrayElement$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ArrayElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ArrayElement$vtype _jc_soot_jimple_spark_pag_ArrayElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ArrayElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ArrayElement$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ArrayElement_H_ */
